function RSwCUI

% RSwCUI:
% GUI interface main program for evaluating amyloid PET radiotracers based on CUI.

% ********************************
% Version0.1: RSwCUI 
% Updated on: 01 Nov 2017.
% Written by: Ying-Hwey, Nai
% ********************************

% Initialise the directories.
[inputFcn,timeRef] = CUI_startup(pwd);

%% Create the basic GUI.
% Get the window screen size.
scrsz = get(0,'ScreenSize');
fontSize = 0.5;
% Create figure.
figMain = figure('Name','Radiotracer Screening with CUI','Position',[scrsz(3)/8 scrsz(4)/8 3*scrsz(3)/4 3*scrsz(4)/4],...
    'color',[0 0 0],'NumberTitle','off','resize','off','menubar','none','ColorMap',gray(64));
% Create Input panel.
batchPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Batch Processing','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.03 0.9 0.23 0.08],'visible','on','tag','batchPanel');
inputPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Required Inputs','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.03 0.64 0.23 0.25],'visible','on','tag','inputPanel');
optionsPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Options','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.03 0.15 0.23 0.48],'visible','on','tag','optionsPanel');
infoPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Progress','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.03 0.03 0.23 0.11],'visible','on','tag','infoPanel');
% Create Output panel to display images.
outputPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Outputs','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.74 0.51 0.23 0.47],'visible','on','tag','outputPanel');
cuiPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Tracer Evaluation','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.74 0.15 0.23 0.35],'visible','on','tag','cuiPanel');
displayPanel = uipanel('parent',figMain,'backgroundcolor',[0 0 0],'title','Display','ForegroundColor',[1 1 1],...
    'FontSize',12,'Position',[0.27 0.03 0.46 0.95],'visible','on','tag','displayPanel');
displayAxesTAC = axes('parent',displayPanel,'units','normalized','position',[0.1 0.56 0.85 0.4],'color',[0 0 0],...
    'HandleVisibility','off','tag','displayAxesTAC','visible','off','fontsize',15);           %#ok
displayAxesSUVR = axes('parent',displayPanel,'units','normalized','position',[0.1 0.07 0.85 0.4],'color',[0 0 0],...
    'HandleVisibility','off','tag','displayAxesSUVR','visible','off','fontsize',15);           %#ok

%% Create the details.
infoText = uicontrol(infoPanel,'style','text','Units','normalized','position',[0.03 0.08 0.94 0.84],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string',{'Select the appropriate excel file for batch processing or fill in the tracer inputs individually.';'Click on "Simulate!" Button to start simulations.'},'FontSize',11,'HorizontalAlignment','left','tag','infoText'); %#ok
% Batch Panel.
batchText = uicontrol(batchPanel,'style','text','Units','normalized','position',[0.02 0.2 0.32 0.55],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Excel Filename:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','batchText'); %#ok
batchInput = uicontrol(batchPanel,'style','edit','Units','normalized','position',[0.35 0.3 0.52 0.5],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','batchInput'); %#ok
batchButton = uicontrol(batchPanel,'style','pushbutton','Units','normalized','position',[0.88 0.3 0.1 0.5],...
    'string','...','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','batchButton','callback',{@batchButton_Callback}); %#ok

% Input Panel.
runButton = uicontrol('parent',figMain,'style','pushbutton','units','normalized','string','Simulate!',...
    'FontSize',14,'FontWeight','bold','Position',[0.74 0.07 0.23 0.05],'visible','on','tag','runButton','callback',{@runButton_Callback});   %#ok
% Create the inputs edit textbox and push buttons.
tracerNameTxt = uicontrol(inputPanel,'style','text','Units','normalized','position',[0.02 0.81 0.53 0.14],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Tracer Name:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','tracerNameTxt'); %#ok
tracerNameInput = uicontrol(inputPanel,'style','edit','Units','normalized','position',[0.57 0.82 0.41 0.14],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','tracerNameInput'); %#ok
LipoTxt = uicontrol(inputPanel,'style','text','Units','normalized','position',[0.02 0.62 0.53 0.14],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Lipophilicity:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','lipoTxt'); %#ok
LipoInput = uicontrol(inputPanel,'style','edit','Units','normalized','position',[0.57 0.63 0.41 0.14],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','lipoInput'); %#ok
VxTxt = uicontrol(inputPanel,'style','text','Units','normalized','position',[0.02 0.43 0.53 0.14],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Molecular Volume (A/mol):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','VxTxt'); %#ok
VxInput = uicontrol(inputPanel,'style','edit','Units','normalized','position',[0.57 0.44 0.41 0.14],...
    'string','','fontunits','normalized','FontSize',fontSize-0.05,'HorizontalAlignment','left','tag','VxInput'); %#ok
KdTxt = uicontrol(inputPanel,'style','text','Units','normalized','position',[0.02 0.24 0.53 0.14],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Dissociation Constant (nM):','fontunits','normalized','FontSize',fontSize-0.05,'HorizontalAlignment','left','tag','kdTxt'); %#ok
KdInput = uicontrol(inputPanel,'style','edit','Units','normalized','position',[0.57 0.25 0.41 0.14],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','kdInput'); %#ok
isotopeTxt = uicontrol(inputPanel,'style','text','Units','normalized','position',[0.02 0.05 0.53 0.14],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Isotope:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','isotopeTxt'); %#ok
isotopeInput = uicontrol(inputPanel,'style','popupmenu','Units','normalized','position',[0.57 0.06 0.41 0.14],...
    'string',{'C-11';'F-18'},'fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','isotopeList'); %#ok
% Options Panel.
HCmciADrText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.89 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','HC-MCI/MCI-AD ratio:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','HCmciADrText'); %#ok
HCmciADrInput = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.91 0.41 0.07],...
    'string','0.5','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','HCmciADrInput'); %#ok
simNoText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.8 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','No of Simulations:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','simNoText'); %#ok
simNoInput = uicontrol(optionsPanel,'style','popupmenu','Units','normalized','position',[0.57 0.82 0.41 0.07],...
    'string',{'1000';'2000';'3000'},'fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','simNoInput'); %#ok
% Bavail-HC
BavailHCtext = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.71 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Bavail (HC):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailHCtext'); %#ok
BavailHCfix = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.73 0.18 0.07],...
    'string','4','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailHCfix'); %#ok 0.41
BavailHCtext2 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.76 0.71 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','(','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailHCtext2'); %#ok
BavailHCvar = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.8 0.73 0.15 0.07],...
    'string','0.80','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailHCvar'); %#ok 0.41
BavailHCtext3 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.97 0.71 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string',')','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailHCtext3'); %#ok
% Bavail-MCI
BavailMCItext = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.62 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Bavail (MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailMCItext'); %#ok
BavailMCIfix = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.64 0.18 0.07],...
    'string','20','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailMCIfix'); %#ok
BavailMCItext2 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.76 0.62 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','(','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailMCItext2'); %#ok
BavailMCIvar = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.8 0.64 0.15 0.07],...
    'string','0.35','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailMCIvar'); %#ok 0.41
BavailMCItext3 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.97 0.62 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string',')','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailMCItext3'); %#ok
% Bavail-AD
BavailADtext = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.53 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Bavail (AD):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailADtext'); %#ok
BavailADfix = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.55 0.18 0.07],...
    'string','50','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailADfix'); %#ok
BavailADtext2 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.76 0.53 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','(','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailADtext2'); %#ok
BavailADvar = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.8 0.55 0.15 0.07],...
    'string','0.20','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailADvar'); %#ok 0.41
BavailADtext3 = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.97 0.53 0.02 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string',')','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BavailADtext3'); %#ok
% Others
noiseLvlText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.44 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Noise Level (%):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','noiseLvlText'); %#ok
noiseLvlInput = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.46 0.41 0.07],...
    'string','3','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','noiseLvlInput'); %#ok
noiseDurationText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.35 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Noise Period (min):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','noiseDurationText'); %#ok
noiseDurationInput = uicontrol(optionsPanel,'style','popupmenu','Units','normalized','position',[0.57 0.37 0.41 0.07],...
    'string',{'8-90';'8-120';'8-150'},'value',3,'fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','noiseDurationInput'); %#ok
suvrText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.27 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','SUVR Time Window (min):','fontunits','normalized','FontSize',fontSize-0.05,'HorizontalAlignment','left','tag','suvrText'); %#ok
suvrInput = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.57 0.29 0.41 0.07],...
    'string','40-60','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','suvrTWinput'); %#ok
saveImgText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.18 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Output Image Format:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','saveImgText'); %#ok
saveImgButton = uicontrol(optionsPanel,'style','popupmenu','Units','normalized','position',[0.57 0.2 0.41 0.07],...
    'string',{'.png';'.mat'},'fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','saveImgList'); %#ok
outDirText = uicontrol(optionsPanel,'style','text','Units','normalized','position',[0.02 0.09 0.53 0.075],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Output Directory:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','outDirText'); %#ok
outDirButton = uicontrol(optionsPanel,'style','pushbutton','Units','normalized','position',[0.57 0.12 0.41 0.07],...
    'string','...','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','outDirButton','callback',{@dirButton_Callback}); %#ok
outDirInput = uicontrol(optionsPanel,'style','edit','Units','normalized','position',[0.02 0.03 0.96 0.07],...
    'string',pwd,'fontunits','normalized','FontSize',fontSize-0.1,'HorizontalAlignment','left','tag','outDirInput'); %#ok

% Output Panel.
fpTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.91 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Extrapolated fp:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','fpTxt'); %#ok
fpOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.92 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','fpOutput'); %#ok
fNDTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.81 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Extrapolated fND:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','fNDTxt'); %#ok
fNDOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.82 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','fNDOutput'); %#ok
K1Txt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.71 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','K1:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','K1Txt'); %#ok
K1Output = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.72 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','K1Output'); %#ok
k2Txt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.61 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','k2:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','k2Txt'); %#ok
k2Output = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.62 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','k2Output'); %#ok
BPndhcTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.51 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','BPnd (HC):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndhcTxt'); %#ok
BPndhcOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.52 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndhcOutput'); %#ok
BPndmciTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.41 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','BPnd (MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndmciTxt'); %#ok
BPndmciOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.42 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndmciOutput'); %#ok
BPndadText = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.31 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','BPnd (AD):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndadText'); %#ok
BPndadOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.32 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','BPndadOutput'); %#ok
SUVRhcTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.21 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','SUVR (HC):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRhcTxt'); %#ok
SUVRhcOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.22 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRhcOutput'); %#ok
SUVRmciTxt = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.11 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','SUVR (MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRmciTxt'); %#ok
SUVRmciOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.12 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRmciOutput'); %#ok
SUVRadText = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.02 0.01 0.36 0.07],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','SUVR (AD):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRadText'); %#ok
SUVRadOutput = uicontrol(outputPanel,'style','text','Units','normalized','position',[0.38 0.02 0.6 0.07],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SUVRadOutput'); %#ok
% CUI
AzHMtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.87 0.36 0.1],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Az (HC-MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','AzHMtext'); %#ok
AzHMoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.88 0.6 0.095],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','AzHMoutput'); %#ok
AzMAtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.73 0.36 0.1],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Az (MCI-AD):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','AzMAtext'); %#ok
AzMAoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.74 0.6 0.1],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','AzMAoutput'); %#ok
EsHMtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.59 0.36 0.095],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Es (HC-MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','EsHMtext'); %#ok
EsHMoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.6 0.6 0.1],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','EsHMoutput'); %#ok
EsMAtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.45 0.36 0.095],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Es (MCI-AD):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','EsMAtext'); %#ok
EsMAoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.46 0.6 0.1],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','EsMAoutput'); %#ok
SrHMtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.31 0.47 0.095],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Sr (MCI/HC):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SrHMtext'); %#ok
SrHMoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.32 0.6 0.1],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SrHMoutput'); %#ok
SrMAtext = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.17 0.33 0.095],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','Sr (AD/MCI):','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SrMAtext'); %#ok
SrMAoutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.18 0.6 0.1],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','SrMAoutput'); %#ok
CUIText = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.02 0.02 0.36 0.1],'BackgroundColor',[0 0 0],...
    'ForegroundColor',[1 1 1],'string','CUI:','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','CUIText'); %#ok
CUIOutput = uicontrol(cuiPanel,'style','text','Units','normalized','position',[0.38 0.03 0.6 0.11],...
    'string','','fontunits','normalized','FontSize',fontSize,'HorizontalAlignment','left','tag','CUIoutput'); %#ok

% Get the structure using guidata in the subfunction
figHandles = guihandles(figMain);

% Input the IF data.
figHandles.inputFcn = inputFcn;
figHandles.timeRef = timeRef;
% Load the default information.
figHandles.DefaultOptions = struct('K1var',0.1,'k2var',0.2,'perfusionF',0.6,'capillarySA',150,'alpha',0.7,'K1sf',1.23,'k2SF',1.15,'BPndSF',0.38);

% Save the change you made to the structure
guidata(figMain,figHandles)

% End of function.
end

% Directory Button Callback.
function dirButton_Callback(hObject,eventdata,handles)          %#ok

% Get the figMain.
figMain = ancestor(hObject,'figure');
% Get the structure using guidata in the subfunction
figHandles = guidata(figMain);
% Get the output directory.
outDir = uigetdir(pwd,'Select the output directory:');
% Set the display
set(figHandles.outDirInput,'string',outDir);
% Save the change you made to the structure
guidata(figMain,figHandles)

end

% Batch File Button Callback.
function batchButton_Callback(hObject,eventdata,handles)          %#ok

% Get the figMain.
figMain = ancestor(hObject,'figure');
% Get the structure using guidata in the subfunction
figHandles = guidata(figMain);
% Get the output directory.
[batchFilename,batchFilepath] = uigetfile('.xlsx','Select the xlsx template:');
% Set the display
set(figHandles.batchInput,'string',fullfile(batchFilepath,batchFilename));
% Save the change you made to the structure
guidata(figMain,figHandles)

end

% Run Button Function.
function runButton_Callback(hObject,eventdata,handles)          %#ok
% Function to carry out simulations.
% Get the figMain.
figMain = ancestor(hObject,'figure');
% Get the structure using guidata in the subfunction
figHandles = guidata(figMain);

%% Get the required Options.
% HC-MCI vs. MCI-AD ratio.
HMAratioTxt = get(figHandles.HCmciADrInput,'string');
if isempty(HMAratioTxt); set(figHandles.infoText,'string',{'Pls input HC-MCI/MCI-AD ratio'}); return; end
% Check that the input can be converted to number.
HMAratio = str2double(HMAratioTxt); if isnan(HMAratio); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end

% HC population.
BavailHCfix = get(figHandles.BavailHCfix,'string');
if isempty(BavailHCfix); set(figHandles.infoText,'string',{'Pls input Bavail (HC) fixed value'}); return;  end
% Check that the input can be converted to number.
HCfix = str2double(BavailHCfix); if isnan(HCfix); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end
BavailHCvar = get(figHandles.BavailHCvar,'string');
if isempty(BavailHCvar); set(figHandles.infoText,'string',{'Pls input Bavail (HC) variable value'}); return;  end
% Check that the input can be converted to number.
HCvar = str2double(BavailHCvar); if isnan(HCvar); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end

% MCI population.
BavailMCIfix = get(figHandles.BavailMCIfix,'string');
if isempty(BavailMCIfix); set(figHandles.infoText,'string',{'Pls input Bavail (MCI) fixed value'}); return;  end
% Check that the input can be converted to number.
MCIfix = str2double(BavailMCIfix); if isnan(MCIfix); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end
BavailMCIvar = get(figHandles.BavailMCIvar,'string');
if isempty(BavailMCIvar); set(figHandles.infoText,'string',{'Pls input Bavail (MCI) variable value'}); return;  end
% Check that the input can be converted to number.
MCIvar = str2double(BavailMCIvar); if isnan(MCIvar); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end

% AD population.
BavailADfix = get(figHandles.BavailADfix,'string');
if isempty(BavailADfix); set(figHandles.infoText,'string',{'Pls input Bavail (AD) fixed value'}); return;  end
% Check that the input can be converted to number.
ADfix = str2double(BavailADfix); if isnan(ADfix); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end
BavailADvar = get(figHandles.BavailADvar,'string');
if isempty(BavailADvar); set(figHandles.infoText,'string',{'Pls input Bavail (AD) variable value'}); return;  end
% Check that the input can be converted to number.
ADvar = str2double(BavailADvar); if isnan(ADvar); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end

% Noise Level.
noiseLvlInputTxt = get(figHandles.noiseLvlInput,'string');
if isempty(noiseLvlInputTxt); set(figHandles.infoText,'string',{'Pls input Noise Level (%)'}); return;  end
% Check that the input can be converted to number.
noiseSD = str2double(noiseLvlInputTxt) / 100; if isnan(noiseSD); set(figHandles.infoText,'string',{'Input must be numeric!'}); return; end
% SUVR Time Window.
suvrTWinputTxt = get(figHandles.suvrTWinput,'string');
if isempty(suvrTWinputTxt); set(figHandles.infoText,'string',{'Pls input SUVR Time Window (min)'}); return;  end
% Check that the input can be converted to number.
suvrRefTimeWin = suvrTWinputTxt; 
% Noise Period.
noiseDurationInputTxt = get(figHandles.noiseDurationInput,'string'); noiseDurationInputVal = get(figHandles.noiseDurationInput,'value');
% Check that the input can be converted to number.
noiseDuration = noiseDurationInputTxt{noiseDurationInputVal,1}; 
% # of Simulations..
simNoInputTxt = get(figHandles.simNoInput,'string'); simNoInputVal = get(figHandles.simNoInput,'value');
% Check that the input can be converted to number.
noOfSimulations = str2double(simNoInputTxt{simNoInputVal,1}); 
Options = struct('HMAratio',HMAratio,'HCfix',HCfix,'MCIfix',MCIfix,'ADfix',ADfix,'HCvar',HCvar,'MCIvar',MCIvar,'ADvar',ADvar,'noiseSD',noiseSD,'suvrRefTimeWin',suvrRefTimeWin,'noiseDuration',noiseDuration,'noOfSimulations',noOfSimulations);
figHandles.DefaultOptions = processOptions(Options,figHandles.DefaultOptions);

% Get batch inputs info.
batchInputFilename = get(figHandles.batchInput,'string'); 
[batchPathstr,batchName,batchExt] = fileparts(batchInputFilename);
if ~isempty(batchName)
      if ~exist(batchInputFilename)
          set(figHandles.batchInput,'string',''); 
          set(figHandles.infoText,'string',{'No such file... Excel File input is cleared and reset!'}); 
          return; 
      end
      if ~strcmpi(batchExt,'.xlsx') 
          if ~strcmpi(batchExt,'.xls')
              set(figHandles.batchInput,'string','');
              set(figHandles.infoText,'string',{'Incorrect file extension... only Excel File. Input is cleared and reset!'});
          return; 
          end
      end 
end          
if isempty(batchInputFilename) 
    %% Individual processing.
    set(figHandles.infoText,'string',{'Starting individual simulation ...'});
    % Get the inputs.
    % MLogP
    MLogPtxt = get(figHandles.lipoInput,'string');
    if isempty(MLogPtxt); set(figHandles.infoText,'string',{'Pls input MLogP!'}); return;  end
    % Check that the input can be converted to number.
    logP = str2double(MLogPtxt); if isnan(logP); set(figHandles.infoText,'string',{'MLogP must be numeric!'}); return; end
    % Vx
    Vxtxt = get(figHandles.VxInput,'string');
    if isempty(Vxtxt); set(figHandles.infoText,'string',{'Pls input Vx!'}); return; end
    % Check that the input can be converted to number.
    Vx = str2double(Vxtxt); if isnan(Vx); set(figHandles.infoText,'string',{'Vx must be numeric!'}); return; end
    % Kd
    Kdtxt = get(figHandles.kdInput,'string');
    if isempty(Kdtxt); set(figHandles.infoText,'string',{'Pls input Kd!'}); return; end
    % Check that the input can be converted to number.
    Kd = str2double(Kdtxt); if isnan(Kd); set(figHandles.infoText,'string',{'Kd must be numeric!'}); return; end
    if get(figHandles.isotopeList,'value') == 1
        halfLife = 20.3; % 'C-11'
    elseif get(figHandles.isotopeList,'value') == 2
        halfLife = 109.8; % 'F-18'
    else
        error('Not possible to get here!')
    end
    if ~isempty(get(figHandles.CUIoutput,'string'))
        set(figHandles.displayAxesSUVR,'visible','off');       
    end
    % Get the kinetic and basic parameters.
    [kmParams,inputParams] = generateKineticParams(logP,Vx,Kd,halfLife,figHandles.DefaultOptions);
    % Kinetic Modelling.
    kmData = kmModelling(kmParams.K1,kmParams.k2,kmParams.BPndHC,kmParams.BPndMCI,kmParams.BPndAD,figHandles.inputFcn,figHandles.timeRef,figHandles.DefaultOptions);
    % Plot out TACs. and updates display data.
    set(figHandles.fpOutput,'string',sprintf('%2.3f',inputParams.fp))
    set(figHandles.fNDOutput,'string',sprintf('%2.3f',inputParams.fND))
    set(figHandles.K1Output,'string',sprintf('%2.3f',kmParams.K1))
    set(figHandles.k2Output,'string',sprintf('%2.3f',kmParams.k2))
    set(figHandles.BPndhcOutput,'string',sprintf('%2.3f',kmParams.BPndHC))
    set(figHandles.BPndmciOutput,'string',sprintf('%2.3f',kmParams.BPndMCI))
    set(figHandles.BPndadOutput,'string',sprintf('%2.3f',kmParams.BPndAD))
    set(figHandles.SUVRhcOutput,'string',sprintf('%2.3f',kmData.SUVRhc))
    set(figHandles.SUVRmciOutput,'string',sprintf('%2.3f',kmData.SUVRmci))
    set(figHandles.SUVRadOutput,'string',sprintf('%2.3f',kmData.SUVRad))
    % Plot the TACs.
    delete(legend); cla(figHandles.displayAxesTAC);cla(figHandles.displayAxesSUVR); set(figHandles.displayAxesSUVR,'visible','off'); 
    set(figHandles.displayAxesTAC,'visible','off'); cla(figHandles.displayAxesTAC)
    plot(figHandles.displayAxesTAC,kmData.TACad(:,1)/60,kmData.TACad(:,2),'color','r','linewidth',3); hold on;
    plot(figHandles.displayAxesTAC,kmData.TACmci(:,1)/60,kmData.TACmci(:,2),'color','c','linewidth',3);
    plot(figHandles.displayAxesTAC,kmData.TAChc(:,1)/60,kmData.TAChc(:,2),'color','g','linewidth',3);
    plot(figHandles.displayAxesTAC,kmData.TACref(:,1)/60,kmData.TACref(:,2),'color','w','linewidth',3);
    set(figHandles.displayAxesTAC,'color','k','fontunits','pixel','fontsize',18,'Xcolor','w','Ycolor','w','linewidth',2)
    xlim([0 90]); xlabel('Time (mins)'); ylabel('Radioactivity (kBq/mL)'); ylim('auto')
    legend({'AD','MCI','HC','Reference'},'edgecolor','w','textcolor','w','linewidth',1.5)
    set(figHandles.displayAxesTAC,'visible','on');

    %% Create a new figure for saving TACs plot!
    figName = get(figHandles.tracerNameInput,'string');
    outDir = get(figHandles.outDirInput,'string');
    formatVal = get(figHandles.saveImgList,'value'); formatString = get(figHandles.saveImgList,'string');
    TACplotGeneration(kmData,outDir,figName,formatString{formatVal});
    % Population Realizations.    
    set(figHandles.infoText,'string',{'Carrying out Simulation ... '})
    uiwait(figMain,1)
    simData = populationRealizations(kmParams.K1,kmParams.k2,inputParams.fND,inputParams.Kd,inputParams.halfLife,figHandles.inputFcn,figHandles.timeRef,figHandles.DefaultOptions);
    % Prompt that action is completed.
    uiwait(figMain,1)
    set(figHandles.infoText,'string',{'Simulations Completed!'})
    % Plot population distributions.    
    popData = plotPopulationBoxplot(simData,outDir,figName,formatString{formatVal});
    boxplot(figHandles.displayAxesSUVR,popData,{'HC','MCI','AD'},'widths',0.7,'colors','cyr'); 
    set(figHandles.displayAxesSUVR,'color',[0 0 0]);
    ylabel(figHandles.displayAxesSUVR,'Simulated SUVR','color',[1 1 1],'fontsize',13); xlabel(figHandles.displayAxesSUVR,'Representative Subject Groups','color',[1 1 1],'fontsize',13);
    set(figHandles.displayAxesSUVR,'color',[0 0 0]); 
    set(figHandles.displayAxesSUVR,'xticklabel',{'HC','MCI','AD'},'Xcolor','w','Ycolor','w','linewidth',2);
    hold off;
    if ~isempty(get(figHandles.CUIoutput,'string'))
        set(figHandles.displayAxesSUVR,'visible','on');       
    end
    % CUI determination.
    CUIdata = tracerEvaluation(simData,figHandles.DefaultOptions);
    % Display CUI values.
    set(figHandles.CUIoutput,'string',sprintf('%2.3f',CUIdata.CUI));
    % Display Az.
    set(figHandles.AzHMoutput,'string',sprintf('%2.3f',CUIdata.Az.HCtoMCI.param.AUROC))
    set(figHandles.AzMAoutput,'string',sprintf('%2.3f',CUIdata.Az.MCItoAD.param.AUROC));
    % Display Es.
    set(figHandles.EsHMoutput,'string',sprintf('%2.3f',CUIdata.Es.HCtoMCI));
    set(figHandles.EsMAoutput,'string',sprintf('%2.3f',CUIdata.Es.MCItoAD));
    % Display Sr.
    set(figHandles.SrHMoutput,'string',sprintf('%2.3f',CUIdata.Sr.HCtoMCI));
    set(figHandles.SrMAoutput,'string',sprintf('%2.3f',CUIdata.Sr.MCItoAD));
    % Store the mainData.
    CUIeval.inputParams     = inputParams;
    CUIeval.kmData          = kmData;
    CUIeval.populationData  = simData;
    CUIeval.CUIdata         = CUIdata;
    CUIeval.Options         = figHandles.DefaultOptions;
    % Save the evaluation results.
    figHandles.data = CUIeval;
    save(fullfile(outDir,[figName '.mat']),'CUIeval')
    % Save the change you made to the structure
    guidata(figMain,figHandles)
else
    % Read the excel file.
    try
        [~,~,allData] = xlsread(batchInputFilename,'CUItemplate');
    catch
        set(figHandles.infoText,'string',{'Error reading excel input! Please check excel input!'});
    end
    set(figHandles.infoText,'string',{'Starting batch simulation ...'});
    % Determine the no of tracers.
    listSize = size(allData); 
    % Ensure that there are no missing fields.
    for rowNo = 1:listSize(1)-1
        for colNo = 1:5
            if isnan(allData{rowNo+1,colNo})
                set(figHandles.infoText,'string',{'There are missing fields! Pls check again!'}); return
            end
        end
    end
    % Initialise CUIoutput.
    CUIoutput = {'Tracer Name','fp','fND','K1','k2','BPndHC','BPndMCI','BPndAD','SUVRhc','SUVRmci','SUVRad','Az(HC-MCI)','Az(MCI-AD)','Es(HC-MCI)','Es(MCI-AD)','Sr(HC-MCI)','Sr(MCI-AD)','CUI'};
    cla(figHandles.displayAxesSUVR); set(figHandles.displayAxesSUVR,'visible','off')
    %% Loop though the tracers.
    for tracerNo = 2:listSize(1)        
        % Feed in the inputs.
        % TracerName.
        set(figHandles.tracerNameInput,'string',allData{tracerNo,1});
        figName = allData{tracerNo,1};
        % MLogP.
        set(figHandles.lipoInput,'string',double(allData{tracerNo,2}));
        logP = double(allData{tracerNo,2});        
        % Vx
        set(figHandles.VxInput,'string',double(allData{tracerNo,3}));        
        Vx = double(allData{tracerNo,3}); 
        % Kd
        set(figHandles.kdInput,'string',double(allData{tracerNo,4}));        
        Kd = double(allData{tracerNo,4});
        switch allData{tracerNo,5}
            case 'C-11'
                halfLife = 20.3; %
                set(figHandles.isotopeList,'value',1)
            case 'F-18'
                halfLife = 109.8; %
                set(figHandles.isotopeList,'value',2)
            otherwise
                error('Not possible to get here!')
        end
        % Clear output from previous.
        set(figHandles.CUIoutput,'string',''); set(figHandles.AzHMoutput,'string',''); set(figHandles.AzMAoutput,'string',''); 
        set(figHandles.EsHMoutput,'string',''); set(figHandles.EsMAoutput,'string',''); set(figHandles.SrHMoutput,'string','');
        set(figHandles.SrMAoutput,'string','');
        set(figHandles.fpOutput,'string',''); set(figHandles.fNDOutput,'string','')
        set(figHandles.K1Output,'string',''); set(figHandles.k2Output,'string','')
        set(figHandles.BPndhcOutput,'string',''); set(figHandles.BPndmciOutput,'string','')
        set(figHandles.BPndadOutput,'string',''); set(figHandles.SUVRhcOutput,'string','')
        set(figHandles.SUVRmciOutput,'string',''); set(figHandles.SUVRadOutput,'string','')
        % Get the kinetic and basic parameters.
        [kmParams,inputParams] = generateKineticParams(logP,Vx,Kd,halfLife,figHandles.DefaultOptions);
        % Kinetic Modelling.
        kmData = kmModelling(kmParams.K1,kmParams.k2,kmParams.BPndHC,kmParams.BPndMCI,kmParams.BPndAD,figHandles.inputFcn,figHandles.timeRef,figHandles.DefaultOptions);
        
        % Plot out TACs. and updates display data.
        set(figHandles.fpOutput,'string',sprintf('%2.3f',inputParams.fp))
        set(figHandles.fNDOutput,'string',sprintf('%2.3f',inputParams.fND))
        set(figHandles.K1Output,'string',sprintf('%2.3f',kmParams.K1))
        set(figHandles.k2Output,'string',sprintf('%2.3f',kmParams.k2))
        set(figHandles.BPndhcOutput,'string',sprintf('%2.3f',kmParams.BPndHC))
        set(figHandles.BPndmciOutput,'string',sprintf('%2.3f',kmParams.BPndMCI))
        set(figHandles.BPndadOutput,'string',sprintf('%2.3f',kmParams.BPndAD))
        set(figHandles.SUVRhcOutput,'string',sprintf('%2.3f',kmData.SUVRhc))
        set(figHandles.SUVRmciOutput,'string',sprintf('%2.3f',kmData.SUVRmci))
        set(figHandles.SUVRadOutput,'string',sprintf('%2.3f',kmData.SUVRad))
        % Plot the TACs.        
        if tracerNo ~= 2 || ~isempty(get(figHandles.CUIoutput,'string'))
            delete(legend); cla(figHandles.displayAxesSUVR); 
            set(figHandles.displayAxesSUVR,'visible','off'); cla(figHandles.displayAxesTAC); 
            set(figHandles.displayAxesTAC,'visible','off');                         
        end   
        set(figHandles.infoText,'string',{sprintf('Carrying out Simulation of %s ... ',figName)})
        uiwait(figMain,1)
        % Plot         
        plot(figHandles.displayAxesTAC,kmData.TACad(:,1)/60,kmData.TACad(:,2),'color','r','linewidth',3); hold (figHandles.displayAxesTAC,'on');
        plot(figHandles.displayAxesTAC,kmData.TACmci(:,1)/60,kmData.TACmci(:,2),'color','c','linewidth',3);
        plot(figHandles.displayAxesTAC,kmData.TAChc(:,1)/60,kmData.TAChc(:,2),'color','g','linewidth',3);
        plot(figHandles.displayAxesTAC,kmData.TACref(:,1)/60,kmData.TACref(:,2),'color','w','linewidth',3);
        set(figHandles.displayAxesTAC,'color','k','fontunits','pixel','fontsize',15,'Xcolor','w','Ycolor','w','linewidth',2)
        xlim(figHandles.displayAxesTAC,[0 90]); xlabel(figHandles.displayAxesTAC,'Time (mins)'); ylabel(figHandles.displayAxesTAC,'Radioactivity Concentration (kBq/mL)'); ylim(figHandles.displayAxesTAC,'auto')
        set(figHandles.displayAxesTAC,'yticklabelmode','auto');
        set(figHandles.displayAxesTAC,'xticklabelmode','auto');
        legend(figHandles.displayAxesTAC,{'AD','MCI','HC','Reference'},'edgecolor','w','textcolor','w','linewidth',1.5)
        uiwait(figMain,2); hold(figHandles.displayAxesTAC,'off'); set(figHandles.displayAxesTAC,'visible','on');
        %% Create a new figure for saving TACs plot!        
        outDir = get(figHandles.outDirInput,'string');
        formatVal = get(figHandles.saveImgList,'value'); formatString = get(figHandles.saveImgList,'string');
        TACplotGeneration(kmData,outDir,figName,formatString{formatVal});
        % Population Realizations.                
        simData = populationRealizations(kmParams.K1,kmParams.k2,inputParams.fND,inputParams.Kd,inputParams.halfLife,figHandles.inputFcn,figHandles.timeRef,figHandles.DefaultOptions);
        % Prompt that action is completed.
        set(figHandles.infoText,'string',{sprintf('Finished Simulation of %s ... ',figName)})
        % Plot population distributions.
        uiwait(figMain,1)
        popData = plotPopulationBoxplot(simData,outDir,figName,formatString{formatVal});
        boxplot(figHandles.displayAxesSUVR,popData,{'HC','MCI','AD'},'widths',0.7,'colors','cyr')
        set(figHandles.displayAxesSUVR,'color',[0 0 0],'fontsize',12,'xcolor',[1 1 1],'ycolor',[1 1 1]); 
        ylabel(figHandles.displayAxesSUVR,'Simulated SUVR','color',[1 1 1]); xlabel(figHandles.displayAxesSUVR,'Representative Subject Groups','color',[1 1 1]);hold off;
        uiwait(figMain,1)
        % CUI determination.
        CUIdata = tracerEvaluation(simData,figHandles.DefaultOptions);
        % Display CUI values.
        set(figHandles.CUIoutput,'string',sprintf('%2.3f',CUIdata.CUI));
        % Display Az.
        set(figHandles.AzHMoutput,'string',sprintf('%2.3f',CUIdata.Az.HCtoMCI.param.AUROC));
        set(figHandles.AzMAoutput,'string',sprintf('%2.3f',CUIdata.Az.MCItoAD.param.AUROC));
        % Display Es.
        set(figHandles.EsHMoutput,'string',sprintf('%2.3f',CUIdata.Es.HCtoMCI));
        set(figHandles.EsMAoutput,'string',sprintf('%2.3f',CUIdata.Es.MCItoAD));
        % Display Sr.
        set(figHandles.SrHMoutput,'string',sprintf('%2.3f',CUIdata.Sr.HCtoMCI));
        set(figHandles.SrMAoutput,'string',sprintf('%2.3f',CUIdata.Sr.MCItoAD));
        uiwait(figMain,1)
        % Store the mainData.
        CUIeval.inputParams     = inputParams;
        CUIeval.kmData          = kmData;
        CUIeval.populationData  = simData;
        CUIeval.CUIdata         = CUIdata;
        CUIeval.Options         = figHandles.DefaultOptions;
        compilationData.(figName) = CUIeval;        
        % Save the evaluation results.
        figHandles.data = compilationData;        
        save(fullfile(outDir,[figName '.mat']),'CUIeval')
        % Compile key data for saving to excel file.
        CUIoutput{tracerNo,1} = figName; % Tracer Name
        CUIoutput{tracerNo,2} = inputParams.fp;     % fp
        CUIoutput{tracerNo,3} = inputParams.fND;    % fND
        CUIoutput{tracerNo,4} = kmData.K1;        % K1
        CUIoutput{tracerNo,5} = kmData.k2;        % k2
        CUIoutput{tracerNo,6} = kmData.BPndHC;    % BPndHC
        CUIoutput{tracerNo,7} = kmData.BPndMCI;   % BPndMCI
        CUIoutput{tracerNo,8} = kmData.BPndAD;    % BPndAD
        CUIoutput{tracerNo,9} = kmData.SUVRhc;    % SUVRhc
        CUIoutput{tracerNo,10} = kmData.SUVRmci;   % SUVRmci
        CUIoutput{tracerNo,11} = kmData.SUVRad;   % SUVRad
        CUIoutput{tracerNo,12} = CUIeval.CUIdata.Az.HCtoMCI.param.AUROC; % Az-HC-MCI
        CUIoutput{tracerNo,13} = CUIeval.CUIdata.Az.MCItoAD.param.AUROC; % Az-MCI-AD
        CUIoutput{tracerNo,14} = CUIeval.CUIdata.Es.HCtoMCI; % Es-HC-MCI
        CUIoutput{tracerNo,15} = CUIeval.CUIdata.Es.MCItoAD; % Es-MCI-AD
        CUIoutput{tracerNo,16} = CUIeval.CUIdata.Sr.HCtoMCI; % Sr-HC-MCI
        CUIoutput{tracerNo,17} = CUIeval.CUIdata.Sr.MCItoAD; % Sr-MCI-AD
        CUIoutput{tracerNo,18} = CUIeval.CUIdata.CUI; % CUI
        clear kmData simData CUIdata inputParams
    end
    % Save CUIoutput.
    dateNow = date;
    status = xlswrite(fullfile(outDir,['CUIoutput_' dateNow '.xlsx']),CUIoutput);
    if status == 0
        set(figHandles.infoText,'string',{'Problem saving to excel ...';'Please close excel program.'})
        uiwait(figMain,1)
    end
    %% Compile all the data and plot CUI distribution.
    % Loop through to load the data and compile.
    for tracerNo = 2:listSize(1)        
        loadData = load(fullfile(outDir,[allData{tracerNo,1} '.mat']));
        compiledData(tracerNo-1).data = loadData.CUIeval;
        cuiVal(1,tracerNo-1) = loadData.CUIeval.CUIdata.CUI;
        tracerList{1,tracerNo-1} = allData{tracerNo,1};
    end
    newVal = sort(cuiVal); 
    for n = 1:listSize(1)-1; 
        for c = 1:listSize(1)-1; 
            if newVal(1,n) == cuiVal(1,c)
                newList{1,n} = tracerList{1,c};
            end
        end
    end;   
    bar(figHandles.displayAxesTAC,newVal,'facecolor',[0.5 0.5 0.5]);
    set(figHandles.displayAxesTAC,'color',[0 0 0],'fontsize',10,'xcolor',[1 1 1],'ycolor',[1 1 1]);
    xlim([0 length(newList)+1])
    xList{1,1} = ''; xList(1,2:length(newList)+1) = newList; xList{1,length(newList)+2} = '';
    try
        set(figHandles.displayAxesTAC,'xticklabel',xList,'xtick',0:length(newList)+1,'XTickLabelRotation',-90);
    catch
        set(figHandles.displayAxesTAC,'xticklabel',xList,'xtick',0:length(newList)+1);
    end
    ylabel('CUI','color',[1 1 1]);
    cuiDistributionPlot(newVal,newList,outDir,formatString{formatVal})
    set(figHandles.displayAxesSUVR,'visible','off'); cla(figHandles.displayAxesSUVR)
    uiwait(figMain,1)
    set(figHandles.infoText,'string','Completed all evaluation')
    % Save the change you made to the structure
    guidata(figMain,figHandles)    
end

% End of function.
end

function [inputFcn,timeRef] = CUI_startup(startingDir)
% add CUI directories:

% Get the starting directory.
if nargin == 0
    startingDir = uigetdir(pwd,'Select the directory where CUI program folder is located:');
end

basicDir = fullfile(startingDir,'SupportFcn');
% If path does not exist, prompt user for inputs.
if ~isdir(basicDir)
    startingDir = uigetdir(pwd,'Select the directory where CUI program folder is located:');
end
if isempty(startingDir)
    % User cancelled. Take current dir so no path will be added in the next step.
    startingDir = pwd;
else
    if ~isempty(startingDir)
        % Go to the startingDir.
        cd (startingDir)
    else
        return % User-cancelled
    end
end

if exist(startingDir,'dir')
    % Add the supporting folders' paths.
    addpath(startingDir)
    addpath(fullfile(startingDir,'SupportFcn'))
    addpath(fullfile(startingDir,'Refdata'))    
    % Load the basic data.
    inputFcn = load(fullfile(startingDir,'Refdata','inputFcn.mat'));
    timeRef = load(fullfile(startingDir,'Refdata','timeRef.mat'));
    inputFcn = inputFcn.inputFcn;
    timeRef = timeRef.timeRef;
    % Save path.
    savepath(fullfile(startingDir,'pathdef.m'))   
    % Display paths added.
    disp('***********************************************')
    disp('Added CUIevaluation supporting directories path... ')
    disp('***********************************************')
else
    disp('***********************************************')
    disp('Required path not added!')
    disp('***********************************************')
end
% End of Sub-Function.
end

function [kmParams,inputParams] = generateKineticParams(logP,VxIn,Kd,halfLife,Options)

% Compile input parameters.
Vx = VxIn  * 0.602 / 100;
fND = 7.717 * exp(-1.634 * logP);
fp = 0.936 * power(fND,0.600);
inputParams.logP = logP; inputParams.Vx = Vx; inputParams.fp = fp; 
inputParams.fND = fND; inputParams.Kd = Kd; inputParams.halfLife = halfLife;

% Get Kinetic Parameters.
BPndAD  = fND*(Options.ADfix/Kd)*Options.BPndSF;
BPndMCI = fND*(Options.MCIfix/Kd)*Options.BPndSF;
BPndHC  = fND*(Options.HCfix/Kd)*Options.BPndSF;
combineData = -0.121*power((logP-2.298),2)-2.544*log10(power(Vx,1/3))-2.525;
permeability = power(10,combineData);   % cm / min
% Generate the K1.
K1 = Options.perfusionF*(1-exp(-permeability*Options.capillarySA/Options.perfusionF)) * Options.K1sf; % min-1 or (mL/g)/min
% Generate k2.
k2 = Options.k2SF * K1*(fND/fp); % min-1 *
kmParams.K1 = K1;
kmParams.k2 = k2;
kmParams.BPndHC = BPndHC;
kmParams.BPndMCI = BPndMCI;
kmParams.BPndAD = BPndAD;
% End of Sub-Function.
end

function kmData = kmModelling(K1,k2,BPndHC,BPndMCI,BPndAD,inputFcn,timeRef,Options)
% Kinetic Modelling.
K1 = K1/60; k2 = k2/60;
Cp = inputFcn(:,2); timeWin = inputFcn(:,1);
Ct_HC_out = conv(K1*exp(-k2/(1+BPndHC)*timeWin),Cp);
Ct_MCI_out = conv(K1*exp(-k2/(1+BPndMCI)*timeWin),Cp);
Ct_AD_out = conv(K1*exp(-k2/(1+BPndAD)*timeWin),Cp);
Cref_out = conv(K1*exp(-k2*timeWin),Cp);

% Prepare the output.
if timeRef.endTimes <= timeWin(end,1)    
    Cref(:,1) = timeWin;
    Ct_HC(:,1) = timeWin; Ct_MCI(:,1) = timeWin; Ct_AD(:,1) = timeWin;
    Cref(:,2) = Cref_out(1:length(timeWin),1);
    Ct_HC(:,2) = Ct_HC_out(1:length(timeWin),1); Ct_MCI(:,2) = Ct_MCI_out(1:length(timeWin),1); Ct_AD(:,2) = Ct_AD_out(1:length(timeWin),1);
elseif timeRef.endTimes < length(Cref_out)
    Cref(:,1) = (0:1:endTime)';
    Ct_HC(:,1) = (0:1:endTime)'; Ct_MCI(:,1) = (0:1:endTime)'; Ct_AD(:,1) = (0:1:endTime)';
    % Determine slope of the last 2 point.
    slopeRef = Cref_out(length(timeWin),1) - Cref_out(length(timeWin)-1,1);
    if slopeRef < 0; 
        % OK
    else
        slopeRef = -slopeRef;
    end
    slopeHC = Ct_HC_out(length(timeWin),1) - Ct_HC_out(length(timeWin)-1,1);
    if slopeHC < 0
        % OK
    else
        slopeHC = -slopeHC;
    end
    slopeMCI = Ct_MCI_out(length(timeWin),1) - Ct_MCI_out(length(timeWin)-1,1);
    if slopeMCI < 0
        % OK
    else
        slopeMCI = -slopeMCI;
    end
    slopeAD = Ct_AD_out(length(timeWin),1) - Ct_AD_out(length(timeWin)-1,1);
    if slopeAD < 0
        % OK
    else
        slopeAD = -slopeAD;
    end
    Cref(1:length(timeWin),2) = Cref_out(1:length(timeWin),1); Ct_HC(1:length(timeWin),2) = Ct_HC_out(1:length(timeWin),1);
    Ct_MCI(:,2) = Ct_MCI_out(1:length(timeWin),1); Ct_AD(:,2) = Ct_AD_out(1:length(timeWin),1);
    for e = length(timeWin)+1:timeRef.endTimes+1
        Cref(e,2) = Cref(e-1,2) + slopeRef;    
        Ct_HC(e,2) = Ct_HC(e-1,2) + slopeHC;  Ct_MCI(e,2) = Ct_MCI(e-1,2) + slopeMCI;  Ct_AD(e,2) = Ct_AD(e-1,2) + slopeAD;  
    end
else
    error('Input function time is greater than convoluted time! Not possible to reach here!')    
end

%% Determine SUVR.
[SUVRhc,SUVRmci,SUVRad] = getSUVR(Cref,Ct_HC,Ct_MCI,Ct_AD,Options);
% Convert to mid-frame time data.
for n = 2:length(timeRef.midTimes)
    for c = 1:length(Cref(:,1))
        if Cref(c,1) == timeRef.midTimes(n,1)
            colNo = c;
            TACref(n,1) = timeRef.midTimes(n,1); TAChc(n,1) = timeRef.midTimes(n,1); 
            TACmci(n,1) = timeRef.midTimes(n,1);TACad(n,1) = timeRef.midTimes(n,1);
            TACref(n,2) = Cref(c,2); TAChc(n,2) = Ct_HC(c,2);
            TACmci(n,2) = Ct_MCI(c,2); TACad(n,2) = Ct_AD(c,2);
            continue
        end
    end
end

% Store the data for output.
kmData.K1       = K1*60;
kmData.k2       = k2*60;
kmData.BPndHC   = BPndHC;
kmData.BPndMCI  = BPndMCI;
kmData.BPndAD   = BPndAD;
kmData.TACref   = TACref;
kmData.TAChc    = TAChc;
kmData.TACmci   = TACmci;
kmData.TACad    = TACad;
kmData.SUVRhc   = SUVRhc;
kmData.SUVRmci  = SUVRmci;
kmData.SUVRad   = SUVRad;

% End of Sub-Function.
end

function simData = populationRealizations(K1,k2,fND,Kd,halfLife,inputFcn,timeRef,Options)
% Function to simulate population realization.

% Establishing random no and variations
pd = makedist('Normal','mu',0,'sigma',1);
for simNo = 1:Options.noOfSimulations
    disp(simNo)
    %% Random variation of simulated K1 & k2 for TAC generation.
    r = random(pd);
    K1Var(simNo,1) = K1 + (Options.K1var * r * K1); %#ok
    r = random(pd);
    k2Var(simNo,1) = k2 + (Options.k2var * r * k2); %#ok
    r = random(pd);
    BavAD(simNo,1)  = ((r * Options.ADvar) + 1) * Options.ADfix; 
    r = random(pd);
    BavMCI(simNo,1) = ((r  * Options.MCIvar) +  1) * Options.MCIfix;
    if BavMCI(simNo,1) < 10
        BavMCI(simNo,1) = 10;
    end
    r = random(pd);
    BavHC(simNo,1)  = ((r * Options.HCvar) + 1) * Options.HCfix;
    if BavHC(simNo,1) < 0.5
        BavHC(simNo,1) = 1;
    end
    BPndADvar(simNo,1) = fND*(BavAD(simNo,1)/Kd)*Options.BPndSF;
    BPndMCIvar(simNo,1) = fND*(BavMCI(simNo,1)/Kd)*Options.BPndSF;
    BPndHCvar(simNo,1) = fND*(BavHC(simNo,1)/Kd)*Options.BPndSF;    
    kmData = kmModelling(K1Var(simNo,1),k2Var(simNo,1),BPndHCvar(simNo,1),BPndMCIvar(simNo,1),BPndADvar(simNo,1),inputFcn,timeRef,Options);
    simData(simNo).data = kmData;
    simulatedTACref = noiseSimulate(kmData.TACref,timeRef.endTimes,timeRef.midTimes,timeRef.duration,halfLife,Options);
    simulatedTAChc  = noiseSimulate(kmData.TAChc,timeRef.endTimes,timeRef.midTimes,timeRef.duration,halfLife,Options);
    simulatedTACmci = noiseSimulate(kmData.TACmci,timeRef.endTimes,timeRef.midTimes,timeRef.duration,halfLife,Options);
    simulatedTACad  = noiseSimulate(kmData.TACad,timeRef.endTimes,timeRef.midTimes,timeRef.duration,halfLife,Options);
    simData(simNo).data.simTACref = simulatedTACref; simData(simNo).data.simTAChc = simulatedTAChc;
    simData(simNo).data.simTACmci = simulatedTACmci; simData(simNo).data.simTACad = simulatedTACad;
    simData(simNo).data.midTimes = timeRef.midTimes;
    [simData(simNo).data.SUVRhc,simData(simNo).data.SUVRmci,simData(simNo).data.SUVRad] = getSUVRss(simulatedTACref,simulatedTAChc,simulatedTACmci,simulatedTACad,timeRef.midTimes,Options);
    
end

% End of Sub-Function.
end

function simulatedTAC = noiseSimulate(tacOutput,originalTimes,midTimes,duration,halfLife,Options)
% Calculate the decay constant.
lamda = log(2) / (60 * halfLife);
% Generate SF.
[scalFactor,startNo] = generateSF(tacOutput,originalTimes,lamda,Options);
% Generate pseudo random number.
pd = makedist('Normal','mu',0,'sigma',1);
% Calculate the deviation, dev.
for n = 2:length(tacOutput)
    r = random(pd);
    dev(n,1) = r * scalFactor * sqrt(exp(-lamda * midTimes(n,1)) * tacOutput(n,2) / duration(n,1)); %#ok
end
% Remove dev at early time points.
for devNo = 1:startNo-1; dev(devNo,1) = 0; end
% Simulated TACs.
simulatedTAC  = tacOutput(:,2) + dev .* exp(lamda * midTimes);

% End of Sub-Function.
end

function [scalFactor,startNo] = generateSF(tacInput,originalTimes,lamda,Options)

% Generate the scaling factor for simulation.
% Setup the decay function for integration.
fun = @(t) exp(-lamda*t);

% Integrate through the frames.
for n = 2:length(tacInput)
    AUC(n,1) = integral(fun,originalTimes(n-1,1),originalTimes(n,1)) *  tacInput(n,2); %#ok
    % End of Loop.
end
% Determine the noise period.
[t1,tout] = strtok(Options.noiseDuration,'-');
tout = strtok(tout,'-');
t1 = str2num(t1);
t2 = str2num(tout);
t1 = t1 * 60; t2 = t2 * 60;

% Determine the mean of sd within stated frame times.
frameList = 1:length(originalTimes);
startNo = frameList(originalTimes == t1);
endNo = frameList(originalTimes == t2);
if isempty(startNo)
    startNo = 15;
end
%% Calculate SD for each time point.
sd = sqrt(AUC(startNo:endNo,1)) ./ AUC(startNo:endNo,1);
% Get the mean of the stated frames.
meanSD = mean(sd);
% Get the scalFactor.
scalFactor = Options.noiseSD / meanSD;

end

function [SUVRhc,SUVRmci,SUVRad] = getSUVR(Cref,Ct_HC,Ct_MCI,Ct_AD,Options)

% Get SUVR from TACs.
[t1,tout] = strtok(Options.suvrRefTimeWin,'-');
tout = strtok(tout,'-');
t1 = str2num(t1);
t2 = str2num(tout);
t1 = t1 * 60; t2 = t2 * 60;
SUVref = trapz(t1:1:t2,Cref(t1+1:t2+1,2));
SUVhc = trapz(t1:1:t2,Ct_HC(t1+1:t2+1,2));
SUVmci = trapz(t1:1:t2,Ct_MCI(t1+1:t2+1,2));
SUVad = trapz(t1:1:t2,Ct_AD(t1+1:t2+1,2));
% SUVR
SUVRhc = SUVhc / SUVref;
SUVRmci = SUVmci / SUVref;
SUVRad = SUVad / SUVref;
% End of Sub-Function.
end

function [SUVRhc,SUVRmci,SUVRad] = getSUVRss(refSimulatedTAC,simulatedTAChc,simulatedTACmci,simulatedTACad,midTimes,Options)
% Get SUVR from simulated data.
interpRef = interpData(refSimulatedTAC,midTimes);
interpHC = interpData(simulatedTAChc,midTimes);
interpMCI = interpData(simulatedTACmci,midTimes);
interpAD = interpData(simulatedTACad,midTimes);
[SUVRhc,SUVRmci,SUVRad] = getSUVR(interpRef,interpHC,interpMCI,interpAD,Options);
% End of SUb-Function.
end

function [outData,newXdata] = interpData(yData,xData)
%% Functions to interpolate the data.

% Set up the interpolated x data.
newXdata = (xData(1,1):1:xData(2,1))';
% Get the slope
slope = (yData(2,1) - yData(1,1)) / (xData(2,1) - xData(1,1));
intercept = yData(2,1) - slope * xData(2,1);
% Interpolate the data.
newYdata = intercept + newXdata * slope;
finalXdata = newXdata;
finalYdata = newYdata;
clear newXdata newYdata
% Determine the last time point, whether extrapolation is required.    
for n = 3:length(xData)
    % Set up the interpolated x data.    
    newXdata = (xData(n-1,1)+1:1:xData(n,1))';
    % Get the slope and intercept.
    slope = (yData(n,1) - yData(n-1,1)) / (xData(n,1) - xData(n-1,1));
    intercept = yData(n,1) - slope * xData(n,1);
    % Interpolate the data.
    newYdata = intercept + newXdata * slope;
    finalXdata = cat(1,finalXdata,newXdata);
    finalYdata = cat(1,finalYdata,newYdata);    
    clear newXdata newYdata
end

%% Output the interpolated data.
outData(:,1) = finalXdata;
outData(:,2) = finalYdata;

end

function CUIdata = tracerEvaluation(simData,Options)
% Sub-function for CUI evaluation GUI program to generate ROC, PSS and
% SUVRr data.

%% Compile all 1000 SUVRs for the various groups together.
for n = 1:length(simData)
    hcData(n,1) = simData(n).data.SUVRhc;
    mciData(n,1) = simData(n).data.SUVRmci;
    adData(n,1) = simData(n).data.SUVRad;    
end
%% ROC
% HC & MCI
HCrocMCI = paramroc(hcData,mciData,'normal-normal','',1);
% MCI to AD
MCIrocAD = paramroc(mciData,adData,'normal-normal','',1);

%% SUVRr & COV
hcStdev = std(hcData); mciStdev = std(mciData); adStdev = std(adData);
hcMean = mean(hcData); mciMean = mean(mciData); adMean = mean(adData);
SrHCtoMCI = mciMean / hcMean; SrMCItoAD = adMean / mciMean;
%% PSS
EsHCtoMCI = (mciMean - hcMean) / sqrt((power(hcStdev,2)+power(mciStdev,2))/2);
EsMCItoAD = (adMean - mciMean) / sqrt((power(mciStdev,2)+power(adStdev,2))/2);

% Compile the output data.
CUIdata.Az.HCtoMCI = HCrocMCI;
CUIdata.Az.MCItoAD = MCIrocAD;
CUIdata.Es.HCtoMCI = EsHCtoMCI;
CUIdata.Es.MCItoAD = EsMCItoAD;
CUIdata.Sr.HCtoMCI = SrHCtoMCI;
CUIdata.Sr.MCItoAD = SrMCItoAD;
% Determine CUI.
CUI = (CUIdata.Az.HCtoMCI.param.AUROC*Options.HMAratio+CUIdata.Az.MCItoAD.param.AUROC*(1-Options.HMAratio)) * (CUIdata.Es.HCtoMCI*Options.HMAratio+CUIdata.Es.MCItoAD*(1-Options.HMAratio))...
    * (CUIdata.Sr.HCtoMCI*Options.HMAratio+CUIdata.Sr.MCItoAD*(1-Options.HMAratio));
CUIdata.CUI = CUI;
% End of Sub-Function.
end

function TACplotGeneration(kmData,outDir,figName,figFormat)
% Plot out the TACs and save it!
scrsz = get(0,'ScreenSize');
saveMain = figure('Name','TACs','Position',[scrsz(3)/8 scrsz(4)/8 3*scrsz(3)/5 3*scrsz(4)/4],...
    'color',[0 0 0],'NumberTitle','off','resize','off','menubar','none','ColorMap',gray(64),'visible','off'); 
displayAxes = axes('parent',saveMain,'units','normalized','position',[0.08 0.1 0.85 0.85],'color',[0 0 0],...
    'HandleVisibility','off','tag','displayAxes','visible','off');           
plot(displayAxes,kmData.TACref(:,1)/60,kmData.TACref(:,2),'color','w','linewidth',3); hold on;
plot(displayAxes,kmData.TAChc(:,1)/60,kmData.TAChc(:,2),'color','g','linewidth',3); hold on;
plot(displayAxes,kmData.TACmci(:,1)/60,kmData.TACmci(:,2),'color','c','linewidth',3); 
plot(displayAxes,kmData.TACad(:,1)/60,kmData.TACad(:,2),'color','r','linewidth',3); 
set(displayAxes,'color','k','fontsize',13,'Xcolor','w','Ycolor','w','linewidth',2)
xlim([0 90]); xlabel('Time (mins)'); ylabel('Radioactivity Concentration (kBq/mL)');
legend({'Reference','HC','MCI','AD'},'edgecolor','w','textcolor','w','linewidth',1.5)
set(gcf,'PaperPositionMode','auto')
switch figFormat
    case '.png'
        pngFullFilename = fullfile(outDir,[figName '_TACs.png']);
        print(saveMain,'-dpng',pngFullFilename)
    case '.mat'
        figFullFilename = fullfile(outDir,[figName '_TACs.fig']);
        hgsave(saveMain,figFullFilename)
    otherwise
        error('Incorrect Options input.')
end

% End of Sub-Function.
end

function popData = plotPopulationBoxplot(simData,outDir,figName,figFormat)
% Function to plot SUVR distribution.

for n = 1:length(simData)
    hcData(n,1) = simData(n).data.SUVRhc;
    mciData(n,1) = simData(n).data.SUVRmci;
    adData(n,1) = simData(n).data.SUVRad;    
end
popData = [hcData,mciData,adData]; 

scrsz = get(0,'ScreenSize');
saveMain = figure('Name','populationBoxplot','Position',[scrsz(3)/8 scrsz(4)/8 3*scrsz(3)/5 3*scrsz(4)/4],...
    'color',[0 0 0],'NumberTitle','off','resize','off','menubar','none','ColorMap',gray(64),'visible','off'); 
displayAxes = axes('parent',saveMain,'units','normalized','position',[0.08 0.1 0.85 0.85],'color',[0 0 0],...
    'HandleVisibility','off','tag','displayAxes','visible','off');           
boxplot(displayAxes,popData,{'HC','MCI','AD'},'widths',0.7)
ylabel('SUVR'); xlabel('Representative Subject Groups'); 
switch figFormat
    case '.png'
        pngFullFilename = fullfile(outDir,[figName '_population.png']);
        print(saveMain,'-dpng',pngFullFilename)
    case '.mat'
        figFullFilename = fullfile(outDir,[figName '_population.fig']);
        hgsave(saveMain,figFullFilename)
    otherwise
        error('Incorrect Options input.')
end

end

function cuiDistributionPlot(cuiData,cuiList,outDir,figFormat)
% Function to plot SUVR distribution.

scrsz = get(0,'ScreenSize');
saveMain = figure('Name','CUIdistribution','Position',[scrsz(3)/8 scrsz(4)/8 3*scrsz(3)/5 3*scrsz(4)/4],...
    'color',[0 0 0],'NumberTitle','off','resize','off','menubar','none','ColorMap',gray(64),'visible','off'); 
displayAxes = axes('parent',saveMain,'units','normalized','position',[0.08 0.1 0.85 0.85],'color',[0 0 0],...
    'HandleVisibility','off','tag','displayAxes','visible','off');           
bar(displayAxes,cuiData,'facecolor',[0.5 0.5 0.5]);
set(displayAxes,'color',[0 0 0],'fontsize',10,'xcolor',[1 1 1],'ycolor',[1 1 1]);
xlim([0 length(cuiList)+1])
xList{1,1} = ''; xList(1,2:length(cuiList)+1) = cuiList; xList{1,length(cuiList)+2} = '';
try
    set(displayAxes,'xticklabel',xList,'xtick',0:length(cuiList)+1,'XTickLabelRotation',-90);
catch
    set(displayAxes,'xticklabel',xList,'xtick',0:length(cuiList)+1);
end
ylabel('CUI','color',[1 1 1]);

switch figFormat
    case '.png'
        pngFullFilename = fullfile(outDir,'CUI_distribution.png');
        print(saveMain,'-dpng',pngFullFilename)
    case '.mat'
        figFullFilename = fullfile(outDir,'CUI_distribution..fig');
        hgsave(saveMain,figFullFilename)
    otherwise
        error('Incorrect Options input.')
end

end
