function matchStr = compareCellStr(refCellStr,inCellStr)
% Function is written to output the list of matching expressions in
% the structures.
% uses: regexp(i)

% ----------------
% Program Details.
% ----------------
ProgramDetails.Ver          = '0.1';
ProgramDetails.Name         = 'makeIsotropic';
ProgramDetails.Writer       = 'yhNai';
ProgramDetails.dateOfUpdate = '14Oct2014';                                  %#ok

% -------
% Inputs:
% -------
% refCellStr: a cell array of strings of m x 1 to compare against.
% inCellStr: a single expression or cell array of strings of n x 1 to get 
% the required list present in the baseStruct.

% Outputs:
% matchStr: a list displaying where in the baseStruct, the expressions in
% inStruct are located.

% =========================================================================
% Get the required inputs.
if nargin < 2 
    disp('compareStruct: 2 inputs required!')
    return
end

% Initialise matchStr & storeNo.
matchStr = []; storeNo = 1;

% Determine whether both inputs are structures.
switch iscellstr(refCellStr)
    case 1
        switch iscellstr(inCellStr)            
            case 1                     
                % Determine the size of the inStruct.
                strSiz = size(inCellStr);
                % Loop through the input.
                for strNo = 1:strSiz(1)
                    % Determine if there is a match.
                    matchList = getMatch(inCellStr(strNo,1),refCellStr);                                       
                    % Compile all the matchList values.
                    if ~isempty(matchList)
                        matchStr(1,storeNo) = matchList;                      %#ok
                        % Add storeNo.
                        storeNo = storeNo + 1;
                    end
                end                
            case 0
                switch ischar(inCellStr)
                    % It is a character, use only regexp to get easily!
                    case 1                       
                        % Determine if there is a match.
                        matchList = getMatch(inCellStr,refCellStr);
                        % Compile all the matchList values.
                        if ~isempty(matchList)
                            matchStr = matchList;
                        end
                    otherwise
                        error('Incorrect input: only cell arrays!')
                end
        end
    otherwise
        error('Incorrect input: only cell arrays!')        
end
% End of Main function.
end

function matchList = getMatch(input,refCellStr)    
% Function to get the index of where the match occurs.

% Determine where the match occurs.
matchFlag = strcmp(refCellStr,input);

% Get the size of the refCellStr.
baseSiz = size(refCellStr);

% Initialise matchList.
matchList = [];

% Get the index where the match occurs.
for baseNo = baseSiz(1):-1:1
    if matchFlag(baseNo,1) ~= 0 
        matchList = baseNo;
    end
end

% End of function.
end
