function CUIdata = tracerEvaluation(simData,Options)
% Sub-function for CUI evaluation GUI program to generate ROC, PSS and
% SUVRr data.

if nargin == 0 || isempty(simData)
    error('Error in Program!')
end
if nargin < 2 || isempty(Options)
    error('Error in Program!')
end

%% Compile all 1000 SUVRs for the various groups together.
for n = 1:length(simData)
    hcData(n,1) = simData(n).data.SUVRhc;
    mciData(n,1) = simData(n).data.SUVRmci;
    adData(n,1) = simData(n).data.SUVRad;    
end
%% ROC
% HC & MCI
HCrocMCI = paramroc(hcData,mciData,'normal-normal','',1);
% MCI to AD
MCIrocAD = paramroc(mciData,adData,'normal-normal','',1);

%% SUVRr & COV
hcStdev = std(hcData); mciStdev = std(mciData); adStdev = std(adData);
hcMean = mean(hcData); mciMean = mean(mciData); adMean = mean(adData);
SrHCtoMCI = mciMean / hcMean; SrMCItoAD = adMean / mciMean;
%% PSS
EsHCtoMCI = (mciMean - hcMean) / sqrt((power(hcStdev,2)+power(mciStdev,2)/2));
EsMCItoAD = (adMean - mciMean) / sqrt((power(mciStdev,2)+power(adStdev,2)/2));

% Compile the output data.
CUIdata.ROC
CUIdata.PSS.HCtoMCI = EsHCtoMCI;
CUIdata.PSS.MCItoAD = EsMCItoAD;
CUIdata.SUVRr.HCtoMCI = SrHCtoMCI;
CUIdata.SUVRr.MCItoAD = SrMCItoAD;

% End of Main Function.
end